@@ -233,7 +233,7 @@
 (defun list-negp (l1)
   (dolist (i1 l1)
     (unless (zerop1 i1)
-      (return-from list-negp (eq -1 (signum1 i1))))))
+      (return-from list-negp (eql -1 (signum1 i1))))))
 
 (defun tlist-add (l1 l2) (mapcar #'clist-add l1 l2))
 
@@ -346,7 +346,7 @@
 
 (defun untlist (tlist vars)
   (flet ((un1 (list trig)
-	   (flet ((un2 (e)(mul (cadr e)(cons-exp trig (multl (cddr e) vars)))))
+	   (flet ((un2 (e)(mul (cadr e)(ftake* trig (multl (cddr e) vars)))))
 	     (addn (mapcar #'un2 list) t))))
     (addn (mapcar #'un1 tlist '(%sin %cos)) t)))
 
@@ -373,7 +373,7 @@
 			  (if (eq (second r) 'ps)
 			      (mapcar #'(lambda (p)
 					  (list (specdisrep (cons hdr (cdr p)))
-						(cons-exp 'rat (caar p)(cdar p))))
+						(ftake* 'rat (caar p)(cdar p))))
 				      (cddddr r))
 			      (list (list (specdisrep (cons hdr (cdr r))) 0))))))))
       (mlist* (mlist* '$%taylor var order nil)(map-mlist (make1 expr))))))
@@ -414,7 +414,7 @@
   (setq expr (totalspecdisrep expr))
   (let ((v (car (instanciate-variable-list (list var) expr '$series_coeffs 1))))
     (setq v ($ratdisrep v))
-    (labels ((mino (expr)			; find minumum power of v in expr (for mult)
+    (labels ((mino (expr)			; find minimum power of v in expr (for mult)
 	       (let ((op (and (listp expr)(caar expr))))
 		 (cond ((like expr v)   1)	; Trivial case: expr is V itself
 		       ((or ($atom expr)(freeof v expr)) 0)	; `constant' case
