@@ -14,7 +14,6 @@
  		       								 
 
 ($put '$to_poly 2 '$version)
-($load '$polynomialp)
 
 (defmacro opapply (op args)
   `(simplify (cons (list ,op) ,args)))
@@ -594,33 +593,35 @@ to eliminate.
   (new-gentemp type))
 
 (defun new-gentemp (type)
-  (let ((g))
-    (cond 
-     ((eq type '$integer) 
-      (setq g (gentemp *integer-gentemp-prefix*))
-      (setf (get g 'integer-gentemp) t)
-      (mfuncall '$declare g '$integer))
-     
-     ((eq type '$natural_number)
-      (setq g (gentemp *natural-gentemp-prefix*))
-      (setf (get g 'natural-gentemp) t)
-      (mfuncall '$declare g '$integer)
-      (mfuncall '$assume (take '(mgeqp) g 0)))
-	  
-     ((eq type '$real) 
-      (setq g (gentemp *real-gentemp-prefix*))
-      (setf (get g 'real-gentemp) t))
-     
-     ((eq type '$complex)
-      (setq g (gentemp *complex-gentemp-prefix*))
-      (setf (get g 'complex-gentemp) t)
-      (mfuncall '$declare g '$complex))
+  (flet ((%gentemp (prefix)
+           (intern (symbol-name (gensym prefix)) :maxima)))
+    (let ((g))
+      (cond
+       ((eq type '$integer)
+        (setq g (%gentemp *integer-gentemp-prefix*))
+        (setf (get g 'integer-gentemp) t)
+        (mfuncall '$declare g '$integer))
 
-     (t 
-      (setq g (gentemp *general-gentemp-prefix*))
-      (setf (get g 'general-gentemp) t)))
-    
-    g))
+       ((eq type '$natural_number)
+        (setq g (%gentemp *natural-gentemp-prefix*))
+        (setf (get g 'natural-gentemp) t)
+        (mfuncall '$declare g '$integer)
+        (mfuncall '$assume (take '(mgeqp) g 0)))
+
+       ((eq type '$real)
+        (setq g (%gentemp *real-gentemp-prefix*))
+        (setf (get g 'real-gentemp) t))
+
+       ((eq type '$complex)
+        (setq g (%gentemp *complex-gentemp-prefix*))
+        (setf (get g 'complex-gentemp) t)
+        (mfuncall '$declare g '$complex))
+
+       (t
+        (setq g (%gentemp *general-gentemp-prefix*))
+        (setf (get g 'general-gentemp) t)))
+
+      g)))
 
 ;; Find all the new-gentemp variables in an expression e and re-index them starting from 0.
 
