@@ -46,7 +46,7 @@
 	 (push (cons f type) *tr-runtime-warned*)
 	 (when $tr_warn_bad_function_calls
 	   (let ((tabl (cdr (assoc type '((fexpr . (fexpr-warnedp "This may be due to lack of enough translation data *print-base* info."))
-					 (macro . (macro-warnedp "Macros should to be loaded when you are translating."))
+					 (macro . (macro-warnedp "Macros should be loaded when you are translating."))
 					 (undefined . (undefined-warnp "The function was totally undefined. Maybe you want to quote it."))
 					 (punt-nil . (punt-nil-warnp "If you want the value of the function name, use `apply'"))
 					 (mfexpr . (mfexpr-warnedp "MFEXPRS should be loaded at translating time. Use of them in translated code (nay, any code!), is NOT recommended however.")))
@@ -56,11 +56,13 @@
 		   (t
 		    (putprop f t (car tabl))
 		    (terpri)
+		    (finish-output)
 		    (princ "Warning: ")
 		    (mgrind f nil)
 		    (princ " has a function or macro call which has not been translated properly.")
 		    (cond ((cdr tabl)
 			   (terpri)
+			   (finish-output)
 			   (princ (cadr tabl)))))))))))
 
 (defun mapcar-eval (x)
