@@ -26,11 +26,11 @@ or if apply is being used are printed.")
 (declare-top (special derivflag derivlist $labels $values $functions $arrays 
                       $rules $gradefs $dependencies $aliases
 		      $myoptions $props genvar $maxposex $maxnegex $expop $expon
-		      $numer state-pdl *mdebug* *refchkl* *baktrcl*
+		      $numer *mdebug* *refchkl*
 		      $norepeat $detout $doallmxops $doscmxops opers
 		      *mopl* *alphabet* $%% %e-val
 		      $macros linel $ratfac $ratwtlvl
-		      $operators $partswitch *gcdl*
+		      $partswitch *gcdl*
 		      *builtin-$props* $infolists))
 
 (declare-top (unspecial args))
@@ -97,7 +97,7 @@ or if apply is being used are printed.")
 (mapc #'(lambda (x) (setf (symbol-value x) (ncons '(mlist simp))))
       '($values $functions $macros $arrays $myoptions $rules $props))
 
-(defmfun mapply1 (fn args fnname form)
+(defun mapply1 (fn args fnname form)
   (declare (special aryp))
   (cond ((atom fn)
 	 (cond ((functionp fn)
@@ -145,7 +145,7 @@ or if apply is being used are printed.")
 	 (cons '(mqapply) (cons fn args)))))
 
 ;; the last argument to mapply1 for the lineinfo is not correct here..
-(defmfun mcall (fn &rest args)
+(defun mcall (fn &rest args)
   (mapply1 fn args fn nil))
 
 (defun mevalargs (args)
@@ -187,7 +187,6 @@ is EQ to FNNAME if the latter is non-NIL."
   ; are applied to arguments.
   (setq noevalargs nil)
   (let ((params  (cdadr fn))( mlocp  t))
-    (setq loclist (cons nil loclist))
     (do ((a) (p))
 	((or (null params) (and (null args) (not (mdeflistp params))))
 	 (setq args (nreconc a args) params (nreconc p params)))
@@ -208,14 +207,12 @@ is EQ to FNNAME if the latter is non-NIL."
 	     (unless (> (array-total-size ar) (+ (fill-pointer ar) 10))
 	       (setq ar (adjust-array ar (+ (array-total-size ar) 50)	:fill-pointer (fill-pointer ar))))
 	     (vector-push bindlist ar)
-	     ;; rather than pushing all on *baktrcl* it might be good
-	     ;; to make a *last-form* global that is set in meval1
-	     ;; and is pushed here.
 	     (vector-push form ar)
 	     (vector-push params ar)
 	     (vector-push args ar)
 	     (vector-push fnname ar)
 	     (mbind finish2032 args fnname)
+	     (push nil loclist)
 	     (setq finish2033 t)
 	     (let ((aexprp (and aexprp (not (atom (caddr fn)))
 				(eq (caar (caddr fn)) 'lambda))))
@@ -232,7 +229,7 @@ is EQ to FNNAME if the latter is non-NIL."
 (defmspec mprogn (form)
   (mevaln (cdr form)))
 
-(defmfun mevaln (l) ;; called in a few places externally.
+(defun mevaln (l) ;; called in a few places externally.
   (do ((body l (cdr body))
        ($%% '$%%))
       ((null (cdr body)) (meval (car body)))
@@ -251,23 +248,23 @@ is EQ to FNNAME if the latter is non-NIL."
 	  (t
 	   (mapply1 fn (mevalargs argl) (cadr form) form)))))
 
-(defmfun meval (form)
+(defun meval (form)
   (simplifya (meval1 form) nil))
 
 ;;temporary hack to see what's going on:
-(defmfun safe-mgetl (atom inds)
+(defun safe-mgetl (atom inds)
   (and (symbolp atom)
        (let ((props (get atom 'mprops)))
 	 (and props (getl props inds)))))
 
-(defmfun safe-mget (atom inds)
+(defun safe-mget (atom inds)
   (and (symbolp atom)
        (let ((props (get atom 'mprops)))
 	 (and props (getf (cdr props) inds)))))
 
 (defvar *last-meval1-form* nil)
 
-(defmfun meval1 (form)
+(defun meval1 (form)
   (declare (special *nounl* *break-points* *break-step*))
   (cond
     ((atom form)
@@ -292,7 +289,7 @@ is EQ to FNNAME if the latter is non-NIL."
     ((or (and (atom (car form))
               (setq form (cons (ncons (car form)) (cdr form))))
          (atom (caar form)))
-     (let ((*baktrcl* *baktrcl*) transp)
+     (let (transp)
        (prog (u aryp)
          (declare (special aryp))
          (setq *last-meval1-form* form)
@@ -301,8 +298,6 @@ is EQ to FNNAME if the latter is non-NIL."
                      (member (caar form)
                              '(mplus mtimes mexpt mnctimes) :test #'eq))
                 (go c))
-               ;; don't bother pushing mplus and friends on *baktrcl*
-               ;; should maybe even go below aryp.
                ((and *mdebug*
                      (progn
                        ;; if wanting to step, the *break-points*
@@ -430,7 +425,7 @@ is EQ to FNNAME if the latter is non-NIL."
   (and typ (member typ props :test #'eq) (list typ fn)))
 
 
-(defmfun meval2 (newargs old)
+(defun meval2 (newargs old)
   (declare (special aryp))
   (let ((new (cons (car old) newargs)) nosimp)
     (cond ((not (member 'simp (cdar old) :test #'eq))
@@ -451,12 +446,12 @@ is EQ to FNNAME if the latter is non-NIL."
 (defun mparams (vars)
   (mapcar #'mparam (cdr vars)))
 
-(defmfun mop (form)
+(defun mop (form)
   (if (eq (caar form) 'mqapply)
       (cadr form)
       (caar form)))
 
-(defmfun margs (form)
+(defun margs (form)
   (if (eq (caar form) 'mqapply)
       (cddr form)
       (cdr form)))
@@ -466,8 +461,8 @@ is EQ to FNNAME if the latter is non-NIL."
   (if (or flag (numberp val) (member val '(t nil $%e $%pi $%i) :test #'eq))
       (let ((type (if aryp (intl:gettext "an array") (intl:gettext "a function"))))
         (if (and (atom name) (not (equal val name)))
-            (merror (intl:gettext "apply: found ~M evaluates to ~M where ~M was expected.") name val type)
-            (merror (intl:gettext "apply: found ~M where ~M was expected.") val type)))))
+            (merror (intl:gettext "apply: found ~M evaluates to ~M where ~A was expected.") name val type)
+            (merror (intl:gettext "apply: found ~M where ~A was expected.") val type)))))
 
 ;; To store the value of $errormsg in mbind. This value is looked up in the
 ;; routine mbind-doit. This is a hack to get the expected behavior, when the
@@ -488,7 +483,7 @@ wrapper for this."
 	     ((and (null vars) (null args)))
 	     (t (assert fnname (fnname)
 			"Expected a maxima function designator but got NIL.")
-		(merror (intl:gettext "~M arguments supplied to ~M; found: ~M")
+		(merror (intl:gettext "~A arguments supplied to ~M; found: ~M")
 			(if vars (intl:gettext "Too few") (intl:gettext "Too many"))
 			(if (and (consp fnname)
 				 (consp (car fnname))
@@ -548,7 +543,7 @@ wrapper for this."
   (finish-output)
   (values))
 
-(defmfun munbind (vars)
+(defun munbind (vars)
   (dolist (var (reverse vars))
     (cond ((eq (car mspeclist) munbound)
 	   (makunbound var)
@@ -737,7 +732,7 @@ wrapper for this."
 ;; k@1@2:dd; change aa to dd.
 ;; k;
 
-(defmfun mrecord-assign (@-expr value)
+(defun mrecord-assign (@-expr value)
   ;; assume @-expr is  (($@..)  instance-name  field-name)
   (let*
     ((instance (cadr @-expr))
@@ -758,7 +753,7 @@ wrapper for this."
 
 ;; MRECORD-KILL is very similar to MRECORD-ASSIGN. Might consider merging the two somehow.
 
-(defmfun mrecord-kill (@-expr)
+(defun mrecord-kill (@-expr)
   (let*
     ((instance (cadr @-expr))
      (field (caddr @-expr))
@@ -782,7 +777,7 @@ wrapper for this."
      (e ($@-function (meval a) b)))
     (if (eq e b) L e)))
 
-(defun $@-function (in fn)
+(defmfun $@-function (in fn)
   (cond
     ((not (listp in))
      (list '(%@) in fn)) ;; noun form
@@ -810,9 +805,6 @@ wrapper for this."
 (defmspec $defstruct (L)
   `((mlist) ,@(mapcar 'defstruct1 (cdr L))))
 
-;; trivial translation to quiet complaint about lack of translation for this defmspec
-(def%tr $defstruct (x) `($any . (meval ',x)))
-
 (defvar $structures '((mlist)))
 
 (defun defstruct-translate (form)
@@ -869,9 +861,6 @@ wrapper for this."
 
           `(,(car recordname) ,@(mapcar #'meval (cdr recordname))))))))
 
-;; trivial translation to quiet complaint about lack of translation for this defmspec
-(def%tr $new (x) `($any . (meval ',x)))
-
 ;; Following property assignments comprise the Lisp code equivalent to infix("@", 200, 201)
 
 (defprop $@ %@ verb) 
@@ -914,7 +903,7 @@ wrapper for this."
 
 (setf (get 'mlist 'mset_extension_operator) 'mlist-assign)
 
-(defmfun mlist-assign (tlist vlist)
+(defun mlist-assign (tlist vlist)
   ;;  tlist is  ((mlist..)  var[0]... var[n])  of targets
   ;; vlist is either((mlist..)  val[0]... val[n]) of values
   ;; or possibly just one value.
@@ -1062,7 +1051,7 @@ wrapper for this."
 		       bndvals (cons (meval (specrepcheck (caddar l))) bndvals))))
         (t (setq l (append (car l) (cdr l))))))))
 
-(defmfun mevalatoms (exp)
+(defun mevalatoms (exp)
   (cond ((atom exp) (meval1 exp))
 	((member 'array (cdar exp) :test #'eq)
 	 (let (exp1)
@@ -1072,6 +1061,7 @@ wrapper for this."
 	       exp1)))
 	((eq (caar exp) 'mquote) (cadr exp))
 	((member (caar exp) '(msetq $define) :test #'eq)
+	 (twoargcheck exp)
 	 (list (car exp) (cadr exp) (mevalatoms (caddr exp))))
 	((or (and (eq (caar exp) '$ev)
 		  (cdr exp)
@@ -1079,6 +1069,7 @@ wrapper for this."
 	     (eq (caar exp) 'mprogn))
 	 (cons (car exp) (cons (mevalatoms (cadr exp)) (cddr exp))))
 	((member (caar exp) '($sum $product %sum %product) :test #'eq)
+	 (arg-count-check 4 exp)
 	 (if msump
 	     (meval exp)
 	     (list (car exp) (cadr exp) (caddr exp)
@@ -1122,10 +1113,10 @@ wrapper for this."
       ((not (msetqp x)) l)
     (setq l (cons (list (car x) (cadr x) val) l))))
 
-(defmfun msetqp (x)
+(defun msetqp (x)
   (and (not (atom x)) (eq (caar x) 'msetq)))
 
-(defmfun mquotep (x)
+(defun mquotep (x)
   (and (not (atom x)) (eq (caar x) 'mquote)))
 
 (defmspec mquote (form)
@@ -1134,7 +1125,7 @@ wrapper for this."
 (defmfun $subvarp (x)
   (and (not (atom x)) (member 'array (cdar x) :test #'eq) t))
 
-(defmfun mseterr (x y)
+(defun mseterr (x y)
   (if munbindp
       'munbindp
       (merror (intl:gettext "assignment: cannot assign ~M to ~:M") y x)))
@@ -1149,11 +1140,10 @@ wrapper for this."
 	($gensumnum msetchk) ($genindex msetchk) ($fpprintprec msetchk)
 	($floatwidth msetchk) ($parsewindow msetchk) ($optimprefix msetchk)))
 
-(defmfun msetchk (x y)
+(defun msetchk (x y)
   (cond ((member x '(*read-base* *print-base*) :test #'eq)
-	 (cond ((eq y 'roman))
-	       ((or (not (fixnump y)) (< y 2) (> y 36)) (mseterr x y))
-	       ((eq x '*read-base*))))
+	 (unless (typep y '(integer 2 36))
+	   (mseterr x y)))
 	((member x '($linel $fortindent $gensumnum $fpprintprec $floatwidth
 		   $parsewindow) :test #'eq)
 	 (if (not (fixnump y)) (mseterr x y))
@@ -1194,11 +1184,11 @@ wrapper for this."
 	 (if (and y $ratfac)
 	     (merror (intl:gettext "assignment: 'ratfac' and 'ratwtlvl' may not both be used at the same time."))))))
 
-(defmfun numerset (assign-var y)
+(defun numerset (assign-var y)
   (declare (ignore assign-var))
   (mset '$float y))
 
-(defmfun neverset (x assign-val)
+(defun neverset (x assign-val)
   (declare (ignore assign-val))
   (if munbindp 
       'munbindp 
@@ -1212,9 +1202,9 @@ wrapper for this."
         (intl:gettext "assignment: '~:M must be a positive integer. Found: ~:M")
         x y)))
 
-(defmfun mmapev (l)
+(defun mmapev (l)
   (if (null (cddr l))
-      (merror (intl:gettext "~:M: expected two or more arguments; found: ~M") (caar l) (cdr l)))
+      (merror (intl:gettext "~:M: expected two or more arguments; found: ~M") (caar l) (cons '(mlist) (cdr l))))
   (let ((op (getopr (meval (cadr l)))))
     (autoldchk op)
     (badfunchk (cadr l) op nil)
@@ -1223,7 +1213,7 @@ wrapper for this."
 (defmspec $map (l)
   (apply #'map1 (mmapev l)))
 
-(defmfun map1 n
+(defun-maclisp map1 n
   (do ((i n (1- i))
        (argi (setarg n (format1 (arg n))) (format1 (arg (1- i))))
        (op (or (mapatom (arg n)) (mop (arg n))))
@@ -1249,7 +1239,7 @@ wrapper for this."
 	  ((eq (caar res) 'mlist) res)
 	  (t (cons '(mlist) (margs res))))))
 
-(defmfun mmapcar n
+(defun-maclisp mmapcar n
   (do ((ans nil (cons (funcer (arg 1) argl) ans))
        (argl nil nil))
       ((do ((i n (1- i)))
@@ -1268,8 +1258,11 @@ wrapper for this."
        (nreverse ans))))
 
 (defun mapatom (x)
-  (or (symbolp x) (mnump x) ($subvarp x) (stringp x)
-      (and (consp x) (eq (caar x) 'mminus) (mnump (cadr x)))))
+  (or ($atom x)
+      (mnump x)
+      (and (eq (caar x) 'mminus) (mnump (cadr x)))
+      ($subvarp x)
+      (op-equalp x '$@ '%@)))
 
 (defmfun $mapatom (x)
   (if (mapatom (specrepcheck x)) t))
@@ -1329,7 +1322,7 @@ wrapper for this."
 (defmspec $fullmapl (l)
   (apply #'fmapl1 (mmapev l)))
 
-(defmfun fmapl1 (fun &rest args)
+(defun fmapl1 (fun &rest args)
   (let* ((header '(mlist))
 	 (argl (fmap1 fun
 		      (mapcar #'(lambda (z)
@@ -1346,12 +1339,12 @@ wrapper for this."
 	argl
 	(cons header (cdr argl)))))
 
-(defun $outermap (x y &rest z)
+(defmfun $outermap (x y &rest z)
   (if z
     (apply #'outermap1 x y z)
     (fmapl1 x y)))
 
-(defmfun outermap1 n
+(defun-maclisp outermap1 n
   (let (outargs1 outargs2)
     (declare (special outargs1 outargs2))
     (cond ((mxorlistp (arg 2))
@@ -1365,12 +1358,12 @@ wrapper for this."
 		       outargs2 (if (< i n) (listify (- i n))))
 		 (return (fmapl1 #'outermap2 (arg i)))))))))
 
-(defmfun outermap2 (&rest args)
+(defun outermap2 (&rest args)
   (declare (special outargs1 outargs2))
   (unless (null args)
     (apply #'outermap1 (append outargs1 (list (first args)) outargs2))))
 
-(defmfun funcer (fn args)
+(defun funcer (fn args)
   (cond ((member fn '(mplus mtimes mexpt mnctimes) :test #'eq)
 	 (simplify (cons (ncons fn) args)))
 	((or (member fn '(outermap2 constfun) :test #'eq)
@@ -1475,7 +1468,7 @@ wrapper for this."
 (defmspec $remove (form)
   (i-$remove (cdr form)))
 
-(defmfun i-$remove (l)
+(defun i-$remove (l)
   (when (oddp (length l))
     (merror (intl:gettext "remove: number of arguments must be a multiple of 2.")))
   (do ((l l (cddr l)) (vars) (flag nil nil)) ((null l) '$done)
@@ -1527,7 +1520,7 @@ wrapper for this."
 		 (cdr x)))
 	(t (improper-arg-err x fn))))
 
-(defmfun remove1 (vars prop mpropp info funp)
+(defun remove1 (vars prop mpropp info funp)
   (do ((vars vars (cdr vars)) (allflg))
     ((null vars))
     (unless (or (symbolp (car vars)) (stringp (car vars)))
@@ -1575,6 +1568,14 @@ wrapper for this."
       (macsyma-untrace fun))
   (when (and (get fun 'translated) (not (eq $savedef '$all)))
     (fmakunbound fun)
+    ; GCL 2.6.12 doesn't know how to set a compiler macro function with setf
+    #+gcl (si:undef-compiler-macro fun)
+    #-gcl (setf (compiler-macro-function fun) nil)
+    (let ((impl (get fun 'impl-name)))
+      (when (fboundp impl)
+        (fmakunbound impl)))
+    (zl-remprop fun 'impl-name)
+    (zl-remprop fun 'arg-list)
     (zl-remprop fun 'translated-mmacro)
     (zl-remprop fun 'function-mode)
     (when (not (getl fun '(a-expr a-subr)))
@@ -1587,7 +1588,7 @@ wrapper for this."
     (zl-remprop fun 'a-subr)
     (if (not (fboundp fun)) (zl-remprop fun 'translated))))
 
-(defmfun rempropchk (var)
+(defun rempropchk (var)
   (if (and 
         (or
           (not (symbolp var))
@@ -1634,7 +1635,7 @@ wrapper for this."
 (defmspec $remvalue (form)
   (i-$remvalue (cdr form)))
 
-(defmfun i-$remvalue (l)
+(defun i-$remvalue (l)
   (cons '(mlist)
 	(do ((l l (cdr l)) (x) (y)) ((null l) (nreverse x))
 	  (cond ((eq (car l) '$all) (setq l (append l (cdr $values))))
@@ -1644,11 +1645,11 @@ wrapper for this."
 					(remarrelem y (car l)) (car l)))
 				 x)))))))
 
-(defmfun remarrelem (ary form)
+(defun remarrelem (ary form)
   (let ((y (car (arraydims (cadr ary)))))
     (arrstore form (cond ((eq y 'fixnum) 0) ((eq y 'flonum) 0.0) (t munbound)))))
 
-(defmfun remrule (l)
+(defun remrule (l)
   (do ((l l (cdr l)) (u))
       ((null l))
     (cond ((eq (car l) '$all) (setq l (append l (cdr $rules))))
@@ -1658,19 +1659,51 @@ wrapper for this."
 	   (zl-remprop (car l) 'expr) (mremprop (car l) '$rule)
 	   (setf $rules (delete (car l) $rules :count 1 :test #'eq))))))
 
-(defmfun remalias1 (l aliasp)
+(defun remalias1 (l aliasp)
   (do ((l l (cdr l)) (u)) ((null l))
     (cond ((eq (car l) '$all) (setq l (append l (cdr $aliases))))
 	  ((or aliasp (get (car l) 'noun)) (remalias (car l) t))
 	  ((setq u (get (car l) 'verb))
 	   (zl-remprop (car l) 'verb) (zl-remprop u 'noun)))))
 
-(defmfun mremprop (atom ind)
+(defun mremprop (atom ind)
   (let ((props (get atom 'mprops))) (and props (zl-remprop props ind))))
 
-(defmfun mgetl (atom inds)
+(defun mgetl (atom inds)
   (let ((props (get atom 'mprops))) (and props (getl props inds))))
 
+(defmspec $declare_index_properties (form)
+  (let ((a (rest form)))
+    (when (oddp (length a))
+      (merror (intl:gettext "declare_index_properties: number of arguments must be even; found: ~M") `((mlist) ,@a)))
+    (do ((l a (cddr l))) ((null l) '$done)
+      (declare-index-properties-1 (first l) (second l)))))
+
+(defun declare-index-properties-1 (x l)
+  (declare (special $known_index_properties))
+  (if (not (or (symbolp x) (and ($listp x) (every #'symbolp (cdr x)))))
+    (merror (intl:gettext "declare_index_properties: first argument must be a symbol or a list of symbols; found: ~M") x))
+  (if (not ($listp l))
+    (merror (intl:gettext "declare_index_properties: second argument must be a list; found: ~M") l))
+  (if (not (every #'(lambda (y) (member y (cdr $known_index_properties))) (cdr l)))
+    (merror (intl:gettext "declare_index_properties: unknown index property; found: ~M~%~
+                           declare_index_properties: known properties are: ~M") l $known_index_properties))
+  (if ($listp x)
+    (mapcar #'(lambda (x1) (mputprop x1 (cdr l) 'display-indices)) (cdr x))
+    (mputprop x (cdr l) 'display-indices)))
+
+(defmfun $get_index_properties (a)
+  (when (not (symbolp a))
+    (merror (intl:gettext "get_index_properties: argument must be a symbol; found: ~M") a))
+  `((mlist) ,@(mget a 'display-indices)))
+
+(defmspec $remove_index_properties (form)
+  (let ((a (rest form)))
+    (when (not (every #'symbolp a))
+      (merror (intl:gettext "remove_index_properties: every argument must be a symbol; found: ~M") a))
+    (do ((l a (cdr l))) ((null l) '$done)
+      (mremprop (first l) 'display-indices))))
+
 ;;; Define $matrix so that apply(matrix,...) does not need to use Lisp
 ;;; apply -- in GCL, apply is limited to 63 arguments.
 
@@ -1679,7 +1712,7 @@ wrapper for this."
 #+gcl (mputprop '$matrix t 'mlexprp)
 #+gcl (mputprop '$matrix '$matrix 'pname)
 
-#-gcl (defun $matrix (&rest rows) (matrixhelper rows))
+#-gcl (defmfun $matrix (&rest rows) (matrixhelper rows))
 
 ;; Call ONLY from $matrix
 (defun matrixhelper (rows)
@@ -1693,7 +1726,7 @@ wrapper for this."
   (matcheck rows)
   (cons '($matrix) rows))
 
-(defmfun matcheck (l)
+(defun matcheck (l)
   (do ((l1 (cdr l) (cdr l1)) (n (length (car l)))) ((null l1))
     (if (not (= n (length (car l1))))
 	(merror (intl:gettext "matrix: all rows must be the same length.")))))
@@ -1828,7 +1861,7 @@ wrapper for this."
 ;; whereas if it is false they are stored in the function cell
 (defmvar $use_fast_arrays nil)
 
-(defmfun arrstore (l r)
+(defun arrstore (l r)
 	 (let ((fun (caar l)) ary sub (lispsub 0) hashl mqapplyp)
 	   (cond ((setq ary (mget fun 'array))
 		  (dimcheck fun (setq sub (mapcar #'meval (cdr l))) t)
@@ -1923,7 +1956,8 @@ wrapper for this."
       0					; break SAVE files.
       (logand #o77777
 	      (let ((x (car l)))
-		(cond (($ratp x) (merror (intl:gettext "hash function: cannot hash a special expression (CRE or Taylor).")))
+		(cond ((specrepp x)
+		       (merror (intl:gettext "hash function: cannot hash a special expression (CRE, Taylor or Poisson).")))
 		      ((or (fixnump x) (floatp x))
 		       (+ (if (fixnump x) x (floor (+ x 5e-4)))
 			   (* 7 (hasher (cdr l)))))
@@ -2071,7 +2105,7 @@ wrapper for this."
 	(t (mdefchk fun subs t nil)
 	   (mputprop fun (mdefine1 subs (mdefine1 args body)) 'aexpr))))
 
-(defmfun mspecfunp (fun)
+(defun mspecfunp (fun)
   (and (or (getl-lm-fcn-prop fun '(macro))
 	   (getl fun '(mfexpr*))
 	   (and $transrun (get fun 'translated-mmacro))
@@ -2106,20 +2140,20 @@ wrapper for this."
 (defun mdeflistp (l)
   (and (null (cdr l)) ($listp (car l)) (cdar l) (null (cddar l))))
 
-(defmfun mopp (fun)
+(defun mopp (fun)
   (and (not (eq fun 'mqapply))
        (or (mopp1 fun)
 	   (and (get fun 'operators) (not (rulechk fun))
 		(not (member fun rulefcnl :test #'eq)) (not (get fun 'opers))))))
 
-(defmfun mopp1 (fun)
+(defun mopp1 (fun)
   (and (setq fun (get fun 'op)) (not (member fun (cdr $props) :test #'eq))))
 
 ;; maybe should have a separate version, or a macro..
 (defun mapply (a b c)
   (mapply1 a b c nil))
 
-(defun $apply (fun arg)
+(defmfun $apply (fun arg)
   (unless ($listp arg)
     (merror (intl:gettext "apply: second argument must be a list; found: ~M") arg))
   (let ((fun-opr (getopr fun)))
@@ -2161,8 +2195,8 @@ wrapper for this."
 	   (arryp (setq fun (meval1 (setq name (cons (list (caar x) 'array) (cdr x)))))
 		  (if (or (atom fun) (not (eq (caar fun) 'lambda))) (setq fun nil))))
      (cond ((not fun)
-            (cond (stringp (return x)) 
-                  ((member 'edit state-pdl :test #'eq) (terpri)))
+            (when stringp
+              (return x))
             (merror (intl:gettext "fundef: no such function: ~:M") x)))
      (return
        (cons (if (eq (car fun) 'mmacro) '(mdefmacro simp) '(mdefine simp))
@@ -2187,12 +2221,12 @@ wrapper for this."
   (if (not ($listp args)) (merror (intl:gettext "funmake: second argument must be a list; found: ~M") args))
   (mcons-op-args (getopr fun) (cdr args)))
 
-(defmfun mcons-op-args (op args)
+(defun mcons-op-args (op args)
   (if (symbolp op)
       (cons (ncons op) args)
       (list* '(mqapply) op args)))
 
-(defmfun optionp (x)
+(defun optionp (x)
   (and (boundp x)
        (not (member x (cdr $values) :test #'eq))
        (not (member x (cdr $labels) :test #'eq))))
@@ -2304,7 +2338,7 @@ wrapper for this."
 		    (if retp (setq prog '(nil)))))
       (munlocal))))
 
-(defmfun mreturn (&optional (x nil) &rest args)
+(defun mreturn (&optional (x nil) &rest args)
   (cond 
     ((not (null args))
        (merror (intl:gettext "return: too many arguments; found: ~M") `((mlist) ,x ,@args) ))
@@ -2324,16 +2358,16 @@ wrapper for this."
       (wna-err '$subvar))
   (meval (cons '(mqapply array) l)))
 
-(defmfun rat (x y)
+(defun rat (x y)
   `((rat simp) ,x ,y))
 
-(defmfun add2lnc (item llist)
+(defun add2lnc (item llist)
   (unless (memalike item (if ($listp llist) (cdr llist) llist))
     (unless (atom item)
       (setf llist (delete (assoc (car item) llist :test #'equal) llist :count 1 :test #'equal)))
     (nconc llist (ncons item))))
 
-(defmfun bigfloatm* (bf)
+(defun bigfloatm* (bf)
   (unless (member 'simp (cdar bf) :test #'eq)
     (setq bf (cons (list* (caar bf) 'simp (cdar bf)) (cdr bf))))
   (if $float ($float bf) bf))
@@ -2345,7 +2379,7 @@ wrapper for this."
   (let ((dsksetp t))
     (mset (car l) (eval (cadr l)))))
 
-(defmfun dskrat (x)
+(defun dskrat (x)
   (orderpointer (caddar x))
   (mapc #'(lambda (a b) (dskrat-subst a b (cddddr (car x))) ; for TAYLOR forms
 		  (dskrat-subst a b (cdr x)))
@@ -2360,11 +2394,11 @@ wrapper for this."
 	   (dskrat-subst x y (cdr z))
 	   z)))
 
-(defmfun |''MAKE-FUN| (noun-name x)
+(defun |''MAKE-FUN| (noun-name x)
   (simplifya (list (ncons noun-name) (resimplify x)) t))
 
 (macrolet ((|''MAKE| (fun noun)
-	     `(defmfun ,fun (x) (|''MAKE-FUN| ',noun x))))
+	     `(defun ,fun (x) (|''MAKE-FUN| ',noun x))))
   (|''MAKE| $log %log)
   (|''MAKE| $sin %sin) (|''MAKE| $cos %cos) (|''MAKE| $tan %tan)
   (|''MAKE| $cot %cot) (|''MAKE| $sec %sec) (|''MAKE| $csc %csc)
