@@ -90,6 +90,11 @@
       `(ncmuln (list ,@factors) t)))
 
 ;; (TAKE '(%TAN) X) = tan(x)
+;;
+;; Stavros says it's named take:
+;;   "Take as in 'take the sine of ...'.  call or apply might imply
+;;   it's a function call, which it isn't."
+;;
 ;; This syntax really loses.  Not only does this syntax lose, but this macro
 ;; has to look like a subr.  Otherwise, the definition would look like
 ;; (DEFMACRO TAKE ((NIL (OPERATOR)) . ARGS) ...)
@@ -98,23 +103,24 @@
 ;; (TAKE '(%SIN) A) --> (SIMP-%SIN (LIST '(%SIN) A) 1 T)
 
 (defmacro take (operator &rest args)
-  (let ((simplifier (and (not (atom operator))
-			 (eq (car operator) 'quote)
-			 (cdr (assoc (caadr operator) '((%atan  . simp-%atan)
-							(%tan   . simp-%tan)
-							(%log   . simpln)
-							(mabs   . simpabs)
-							(%sin   . simp-%sin)
-							(%cos   . simp-%cos)
-							($atan2 . simpatan2)) :test #'eq)))))
-    (if simplifier
-	`(,simplifier (list ,operator ,@args) 1 t)
-	`(simplifya (list ,operator ,@args) t))))
+	`(simplifya (list ,operator ,@args) t))
 
-(defmacro min%i () ''((mtimes simp) -1 $%i)) ;-%I
-(defmacro 1//2 () ''((rat simp) 1 2))	;1/2
-(defmacro half () ''((rat simp) 1 2))	;1/2
-(defmacro i//2 () ''((mtimes simp) ((rat simp) 1 2) $%i)) ;%I/2
+;; take* does not assume that the arguments are simplified.
+(defmacro take* (operator &rest args)
+  `(simplifya (list ,operator ,@args) nil))
+
+;; Like TAKE, but you only need to specify then name.  So
+;;
+;; (ftake name x y) => (take '(name) x y)
+;;
+;; The name should be the verb form, like %foo.
+(defmacro ftake (name &rest args)
+  `(simplifya (list (list ,name) ,@args)
+	      t))
+
+(defmacro ftake* (name &rest args)
+  `(simplifya (list (list ,name) ,@args)
+	      nil))
 
 (declaim (inline simplify))
 (defun simplify (x)
