@@ -64,7 +64,7 @@
 		   (t (setq treename $current_let_rule_package)))
 	     (let ((nistree (mget treename 'letsimptree))
 		   (nisrules (mget treename 'letrules)))
-	       (setq pat (meval (car l)))
+	       (setq pat (strip-lineinfo (meval (car l))))
 	       (setq replacement (cdr l))
 	       (setq pattern (cond ((atom pat) (list pat))
 				   ((eq (caar pat) 'mtimes)
@@ -147,7 +147,7 @@
 	   (t (setq treename (cadr x))
 	      (if (not (symbolp treename))
 		  (improper-arg-err treename '$remlet))))
-     (setq pattern (meval (car x)))
+     (setq pattern (strip-lineinfo (meval (car x))))
      (when (or (not pattern) (eq '$all pattern))
        (setq nisrules nil nistree nil)
        (unless (eq treename '$default_let_rule_package)
@@ -204,7 +204,7 @@
 
 (defmspec $letsimp (form)		;letsimp(expr,tree1,...,treen)
   (setq form (cdr form))
-  (let* ((expr (meval (pop form)))
+  (let* ((expr (strip-lineinfo (meval (pop form))))
 	 (sw ($ratp expr))
 	 $ratfac)
     (progv (unless sw '(varlist genvar))
@@ -245,7 +245,20 @@
   (let ((num (cadr e)) (denom (cddr e)) $ratexpand)
     (if $letvarsimp (setq varlist (mapcar #'nisletsimp varlist)))
     (let (($ratexpand t))
-      (setq num (nisletsimp (pdis num)) denom (nisletsimp (pdis denom))))
+      ; Construct new CREs based on the numerator and denominator
+      ; of E and disrep them in the VARLIST and GENVAR context from
+      ; E.
+      ;
+      ; NISLETSIMP can change VARLIST and GENVAR, so the order of
+      ; the PDIS and NISLETSIMP forms matter here.  PDISing and
+      ; NISLETSIMPing the numerator before moving on to the
+      ; denominator is not correct.
+      (let ((varlist (mrat-varlist e))
+            (genvar (mrat-genvar e)))
+        (setq num (pdis num)
+              denom (pdis denom)))
+      (setq num (nisletsimp num)
+            denom (nisletsimp denom)))
     (setq e (list '(mquotient) num denom))
     (if $letrat (nisletsimp ($ratexpand e)) e)))
 
@@ -293,22 +306,27 @@
 
 (defun nisnumberpicker (x) 
   (cond ((null x) nil)
-	((not (symbolp (caar x))) (nisnumberpicker (cdr x)))
-	(t (nisswcdr x (nisnumberpicker (cdr x)))))) 
+        ((or (not (symbolp (caar x)))
+             (kindp (caar x) '$constant))
+         ;; Skip over numbers and constants
+         (nisnumberpicker (cdr x)))
+        (t (nisswcdr x (nisnumberpicker (cdr x))))))
 
 (defun nismatch (a b c) 
   (prog (x y newexpt) 
      (setq x (nisextract a))
      (setq y (nisextract b))
      (cond
-       ((cadr y)
-	(cond ((and (equal (car x) (car y))
-		    (setq newexpt (nisexpocheck (cddr x)
-						(cddr y)
-						c))
+       ((listp (cadr y))
+	(cond ((and (listp (cadr x))
+		    (equal (car x) (car y))
+		    (setq c (cons (cons (car x) (car y)) c))
 		    (setq c (nisargschecker (cadr x)
 					    (cadr y)
-					    c)))
+					    c))
+		    (setq newexpt (nisexpocheck (cddr x)
+						(cddr y)
+						c)))
 	       (cond ((equal '(rat) (car newexpt))
 		      (return (cons (cons a (nisbuild x newexpt))
 				    c)))
@@ -331,10 +349,10 @@
 
 (defun nisextract (x)
   (cond ((or (atom x) (eq (caar x) 'rat))
-	 (cons x (cons nil 1)))
+	 (cons x (cons t 1)))
 	((eq 'mexpt (caar x))
 	 (cond ((atom (cadr x))
-		(cons (cadr x) (cons nil (caddr x))))
+		(cons (cadr x) (cons t (caddr x))))
 	       (t (cons (if (member 'array (cdaadr x) :test #'eq)
 			    (list (caaadr x) 'array)
 			    (caaadr x))
@@ -412,7 +430,7 @@
 
 (defun nisbuild (x newexpt) 
   (list '(mexpt)
-	(if (cadr x)
+	(if (listp (cadr x))
 	    (cons (if (symbolp (car x)) (ncons (car x)) (car x))
 		  (cadr x))
 	    (car x))
