@@ -32,10 +32,10 @@ is not included")
 ;; If you change this, you may need to change some of the macros
 ;; below, such as INT and AINT!
 
-#+(or cmu scl sbcl)
+#+(or cmu scl sbcl ecl)
 (deftype integer4 (&optional (low #x-80000000) (high #x7fffffff))
   `(integer ,low ,high))
-#-(or cmu scl sbcl)
+#-(or cmu scl sbcl ecl)
 (deftype integer4 (&optional low high)
   (declare (ignore low high))
   'fixnum)
@@ -906,12 +906,13 @@ is not included")
 (defun datan (x)
   (declare (type double-float x))
   (atan x))
-(defun atan2 (x y)
-  (declare (type single-float x))
-  (atan x y))
-(defun datan2 (x y)
+;; atan2 is the Fortran77 generic name, so it can take any float arg.
+(defun atan2 (y x)
+  (declare (type float y x))
+  (atan y x))
+(defun datan2 (y x)
   (declare (type double-float x y))
-  (atan x y))
+  (atan y x))
 
 (defun dsinh (x)
   (declare (type double-float x))
@@ -1259,7 +1260,7 @@ causing all pending operations to be flushed"
 	   (arg-list
 	    (apply #'append
 		   (map 'list #'(lambda (x)
-				  (cond ((numberp x)
+				  (cond ((bigfloat:numberp x)
 					 (list x))
 					((stringp x)
 					 (list x))
@@ -1687,7 +1688,7 @@ causing all pending operations to be flushed"
 ;;; Revision 1.98  2008/03/06 20:04:10  rtoy
 ;;; Use ~G for list-directed I/O so that numbers come out reasonably.
 ;;; (F77 standard says E or F is used, depending on the magnitude of the
-;;; number.  The parameters for E and F are processer dependent as is the
+;;; number.  The parameters for E and F are processor dependent as is the
 ;;; magnitude used to select between E or F.  This is pretty close to how
 ;;; ~G works in Lisp.)
 ;;;
@@ -1952,7 +1953,7 @@ causing all pending operations to be flushed"
 ;;;   is multi-dimensional.
 ;;;
 ;;; Revision 1.64  2006/01/04 17:53:40  rtoy
-;;; We were not correctly processing intialization of string arrays in
+;;; We were not correctly processing initialization of string arrays in
 ;;; data statements.
 ;;;
 ;;; src/f2cl1.l:
