@@ -49,7 +49,7 @@
 
 (declare-top (special evp $infeval))
 
-(defmfun mrateval (x)
+(defun mrateval (x)
   (let ((varlist (caddar x)))
     (cond ((and evp $infeval) (meval ($ratdisrep x)))
 	  ((or evp
@@ -259,7 +259,7 @@
 	  ($multthru ans))
 	ans)))
 
-(defmfun factor (e &optional (mp nil mp?))
+(defun factor (e &optional (mp nil mp?))
   (let ((tellratlist nil)
 	(varlist varlist)
 	(genvar nil)
@@ -378,6 +378,8 @@
      (when (and ($ratp y) (setq formflag t) (integerp (cadr y)) (equal (cddr y) 1))
        (setq y (cadr y)))
      (when (and (integerp x) (integerp y))
+       (when (zerop y)
+         (merror (intl:gettext "divide: Quotient by zero")))
        (return (cons '(mlist) (multiple-value-list (truncate x y)))))
      (setq varlist vars)
      (mapc #'newvar (reverse (cdr $ratvars)))
@@ -443,7 +445,7 @@
 		   (cons h (cadr x))))
      (return (if formflag h ($totaldisrep h)))))
 
-(defmfun pget (gen)
+(defun pget (gen)
   (cons gen '(1 1)))
 
 (defun m$exp? (x)
@@ -490,7 +492,7 @@
 	(funcflag (not (numberp (cadr x))))
 	(t t)))
 
-(defmfun ratsetup (vl gl)
+(defun ratsetup (vl gl)
   (ratsetup1 vl gl) (ratsetup2 vl gl))
 
 (defun ratsetup1 (vl gl)
@@ -560,11 +562,11 @@
 	    (pget genv))
 	1))
 
-(defmfun ratrep (x varl)
+(defun ratrep (x varl)
   (setq varlist varl)
   (ratrep* x))
 
-(defmfun ratrep* (x)
+(defun ratrep* (x)
   (let (genpairs)
     (orderpointer varlist)
     (ratsetup1 varlist genvar)
@@ -577,7 +579,7 @@
 
 (defvar *withinratf* nil)
 
-(defmfun ratf (l)
+(defun ratf (l)
   (prog (u *withinratf*)
      (setq *withinratf* t)
      (when (eq '%% (catch 'ratf (newvar l)))
@@ -864,8 +866,12 @@
 ;; This control of conversion from float to rational appears to be explained
 ;; nowhere. - RJF
 
-(defmfun maxima-rationalize (x)
+(defun maxima-rationalize (x)
   (cond ((not (floatp x)) x)
+	;; Handle denormalized floats -- see maxima-discuss 2021-04-27 and bug 3777
+	((and (not (= x 0.0)) (< (abs x) COMMON-LISP:LEAST-POSITIVE-NORMALIZED-DOUBLE-FLOAT))
+	 (let ((r ($rationalize x)))
+	   (cons (cadr r) (caddr r))))
 	((< x 0.0)
 	 (setq x (ration1 (* -1.0 x)))
 	 (rplaca x (* -1 (car x))))
@@ -1049,7 +1055,7 @@
   (setq varlist (nconc (sortgreat vlist) varlist)))
 
 (defun sortgreat (l)
-  (and l (nreverse (sort l 'great))))
+  (and l (nreverse (stable-sort l 'great))));FIXME consider a total order function with #'sort
 
 (defun fnewvar (l &aux (*fnewvarsw t))
   (newvar l))
