@@ -16,7 +16,7 @@
 
 (declare-top (special $breakup $noprincipal varlist
 		      leadcoef var *roots *failures wflag nn*
-		      sn* sd* $tellratlist genvar dn* zn))
+		      sn* sd* genvar dn* zn))
 
 
 ;; Compute the poles (roots) of the polynomial D and return them.
@@ -276,15 +276,11 @@
 	 (resm1 (div* nn* dn*) p))))
 
 (defun resm1 (e pole)
-  ;; Call $ratsimp to simplify pole.  Not sure if this is really
-  ;; necessary or desired, but it fixes bug 1504505.  It would be
-  ;; better to fix $taylor, but that seems much harder.
-  (let ((pole ($ratsimp ($rectform pole))))
     ;; Call taylor with silent-taylor-flag t and catch an error.
     (if (setq e (catch 'taylor-catch
                   (let ((silent-taylor-flag t))
                     (declare (special silent-taylor-flag))
                     ;; Things like residue(s/(s^2-a^2),s,a) fails if use -1.
-                    ($taylor e var pole 0))))
+                    ($taylor e var pole 1))))
         (coeff (ratdisrep e) (m^ (m+ (m* -1 pole) var) -1) 1)
-        (merror (intl:gettext "residue: taylor failed.")))))
+        (merror (intl:gettext "residue: taylor failed."))))
