@@ -362,9 +362,12 @@
 
 (declare-top (special vlist lians degree))
 
-(defun getfnsplit (l &aux coef fn)
-  (mapc #'(lambda (x) (if (free x intvar) (push x coef) (push x fn))) l)
-  (cons (muln coef nil) (muln fn nil)))
+(defun getfnsplit (l)
+  (let (coef fn)
+    (dolist (x l (values (muln coef nil) (muln fn nil)))
+      (if (free x intvar)
+          (push x coef)
+          (push x fn)))))
 
 (defun getfncoeff (a form)
   (cond ((null a) 0)
@@ -374,7 +377,8 @@
 					   (getfncoeff (cdr a) form))))
 	((and (listp (car a))
 	      (eq (caaar a) 'mtimes))
-	 (destructuring-let (((coef . newfn) (getfnsplit (cdar a))))
+	 (multiple-value-bind (coef newfn)
+             (getfnsplit (cdar a))
            ;; (car a) is a mtimes expression. We insert coef and newfn as the
            ;; new arguments to the mtimes expression. This causes problems if
            ;;   (1) coef is a mtimes expression too and
@@ -394,20 +398,20 @@
 		    (rplaca a ($expand (resimplify (car a)))))
 		  (getfncoeff a form))
 		 ((and (alike1 (leadop newfn) (leadop form))
-		       (or (alike1 (leadarg newfn) (leadarg form))
-			   (and (mlogp newfn)
-				(logequiv form newfn))))
+                     (or (alike1 (leadarg newfn) (leadarg form))
+                        (and (mlogp newfn)
+                           (logequiv form newfn))))
 		  (ratpl (rform coef)
 			 (prog2 (rplaca a 0)
 			     (getfncoeff (cdr a) form))))
 		 ((do ((vl varlist (cdr vl))) ((null vl))
 		    (and (not (atom (car vl)))
-			 (alike1 (leadop (car vl)) (leadop newfn))
-			 (if (mlogp newfn)
-			     (logequiv (car vl) newfn)
-			     (alike1 (car vl) newfn))
-			 (rplaca (cddar a) (car vl))
-			 (return nil))))
+                       (alike1 (leadop (car vl)) (leadop newfn))
+                       (if (mlogp newfn)
+                           (logequiv (car vl) newfn)
+                           (alike1 (car vl) newfn))
+                       (rplaca (cddar a) (car vl))
+                       (return nil))))
 		 ((let (vlist) (newvar1 (car a)) (null vlist))
 		  (setq cary
 			(ratpl (cdr (ratrep* (car a)))
@@ -415,15 +419,15 @@
 		  (rplaca a 0)
 		  (getfncoeff (cdr a) form))
 		 ((and liflag
-		       (mlogp form)
-		       (mlogp newfn))
+                     (mlogp form)
+                     (mlogp newfn))
 		  (push (dilog (cons (car a) form)) lians)
 		  (rplaca a 0)
 		  (getfncoeff (cdr a) form))
 		 ((and liflag
-		       (polylogp form)
-		       (mlogp newfn)
-		       (logequiv form newfn))
+                     (polylogp form)
+                     (mlogp newfn)
+                     (logequiv form newfn))
 		  (push (mul* (cadar a) (make-li (1+ (car (subfunsubs form)))
 						 (leadarg form)))
 			lians)
