@@ -22,13 +22,13 @@
 ;;; APPLY(F,[X]) is an idiom for funcall.
 
 (defun quoted-symbolp (form)
-  (and (eq (ml-typep form) 'list)
-       (eq 'quote (car form))
-       (symbolp (cadr form))))
+  (and (consp form)
+     (eq 'quote (car form))
+     (symbolp (cadr form))))
 
 (def%tr $apply (form)
   (let* ((fun (dtranslate (cadr form)))
-	 (mode (cond ((atom fun)
+	 (mode (cond ((symbolp fun)
 		      (function-mode-@ fun))
 		     ((quoted-symbolp fun)
 		      (function-mode (cadr fun)))
@@ -50,9 +50,6 @@
 
 (def%tr $maplist (form)
   (destructuring-let (((fun . args) (tr-args (cdr form))))
-    ;; this statement saves the trouble of adding autoload definitions
-    ;; for runtime translator support.
-    (push-autoload-def 'marrayref '(maplist_tr))
     `($any . (maplist_tr ,fun ,@args))))
 
 (def%tr $fullmap (form)
@@ -77,9 +74,6 @@
 
 
 (def%tr $scanmap (form)
-  (push-autoload-def '$scanmap '(scanmap1))
-  ;; there's something more fundamental about the above than
-  ;; just autoload definitions.
   (destructuring-let (((fun . args) (tr-args (cdr form))))
     (call-and-simp '$any 'scanmap1 `((getopr ,fun) ,@args))))
 
@@ -102,10 +96,10 @@
 ;;; SUBSTPART("*",EXP,0) is.
 
 (def%tr $substpart (form)
-  (substpart-translation form t nil '$inflag))
+  (substpart-translation form t nil '$inflag '$substpart))
 
 (def%tr $substinpart (form)
-  (substpart-translation form t nil t))
+  (substpart-translation form t nil t '$substinpart))
 
 (defun for-eval-then-mquote-simp-argl (l)
   ;;       (MAPCAR #'(LAMBDA (U) ;;; consing not important here.
@@ -118,7 +112,7 @@
    (push `(list '(mquote simp) ,(pop l)) v)
    (go loop)))
 
-(defun  substpart-translation (form flag1 flag2 flag3)
+(defun substpart-translation (form flag1 flag2 flag3 fn)
   (let* ((subst-item (dtranslate (cadr form)))
 	 (freevars (free-lisp-vars subst-item))
 	 (argl (tr-args (cddr form))))
@@ -133,7 +127,7 @@
 		      (list  ,@(for-eval-then-mquote-simp-argl
 				(cons subst-item argl)))
 
-		      ,flag1 ,flag2 ,flag3))))
+		      ,flag1 ,flag2 ,flag3 ',fn))))
 	  (t
 	   (setq freevars (tbound-free-vars freevars))
 	   (side-effect-free-check (cadr freevars) (cadr form))
@@ -142,48 +136,24 @@
 				   ,(delete '$piece (car freevars) :test #'equal)
 				   ($piece) ,subst-item)
 				  ,@(for-eval-then-mquote-simp-argl argl))
-		      ,flag1 ,flag2 ,flag3)))))))
-
-;;; This is could be done better on the LISPM
+		      ,flag1 ,flag2 ,flag3 ',fn)))))))
 
 (def%tr $errcatch (form)
-  (setq form (translate `((mprogn) ,@(cdr form))))
-  `(,(car form) . ((lambda (errcatch ret)
-		     (declare (special errcatch))
-		     ;; Very important to declare errcatch special
-		     ;; here because merror uses it to figure out if
-		     ;; someone is catching an error so it can be
-		     ;; signaled in a way that we can catch.
-		     (cond ((null (setq ret
-					(errset ,(cdr form)
-						lisperrprint)))
-			    (errlfun1 errcatch)))
-		     (cons '(mlist) ret))
-		   (cons bindlist loclist) nil)))
-
+  (destructuring-bind (mode . body) (translate `((mprogn) ,@(cdr form)))
+    (declare (ignore mode))
+    (cons '$any `(cons '(mlist) (errcatch ,body)))))
 
 ;;; The MODE of a CATCH could either be the MODE of the last of the PROGN
 ;;; or the mode of the THROW. The THROW may be hard to find, so this goes
 ;;; on the assumption that the mode of the PROGN is enough to tell.
 
 (def%tr $catch (form)
-  (destructuring-let (((mode . body) (translate `((mprogn) . ,(cdr form)))))
-    `(,mode . ((lambda ()
-		 ((lambda (mcatch)
-		    (prog2 nil
-			(catch
-			    'mcatch ,body)
-		      (errlfun1 mcatch)))
-		  (cons bindlist loclist)))))))
+  (destructuring-bind (mode . body) (translate `((mprogn) . ,(cdr form)))
+    (cons mode `(mcatch ,body))))
 
 (def%tr $throw (form)
-  (destructuring-let (((mode . exp) (translate (cadr form))))
-    `(,mode . ((lambda (x)
-		 (cond ((null mcatch)
-			(displa x)
-			(merror (intl:gettext "throw: not within 'catch'."))))
-		 (throw 'mcatch x))
-	       ,exp))))
+  (destructuring-bind (mode . body) (translate (cadr form))
+    (cons mode `($throw ,body))))
 
 ;;; Makelist is a very sorry FSUBR. All these FSUBRS are just to avoid
 ;;; writing LAMBDA. But lots of users use MAKELIST now. 
@@ -204,15 +174,14 @@
       (setq n (dtranslate n))
       `($any .
              ((lambda (,nn)
-                (progn
-                  (setq ,nn ($float ,nn))
-                  (if (numberp ,nn)
-                      (do ((,|0| 1 (add 1 ,|0|)) (,sum nil))
-                          ((> ,|0| ,nn) (cons '(mlist) ,sum))
-                        (setq ,sum 
-                              (cons ,(cdr (tr-local-exp exp)) ,sum)))
-                      (merror
-                       (intl:gettext "makelist: second argument must evaluate to a number; found: ~M") ,nn))))
+                (setq ,nn ($float ,nn))
+                (if (numberp ,nn)
+                    (do ((,|0| 1 (add 1 ,|0|)) (,sum nil))
+                        ((> ,|0| ,nn) (cons '(mlist) ,sum))
+                      (setq ,sum
+                            (cons ,(cdr (tr-local-exp exp)) ,sum)))
+                    (merror
+                     (intl:gettext "makelist: second argument must evaluate to a number; found: ~M") ,nn)))
               ,n))))
     ((= (length form) 3)
      (destructuring-let
@@ -249,8 +218,7 @@
       (setq |0| (dtranslate |0|) n (dtranslate n))
       `($any .
              ((lambda (,|00| ,nn)
-                (progn
-                  (setq ,nn ($float (sub ,nn ,|00|)))
+                (setq ,nn ($float (sub ,nn ,|00|)))
                 (if (numberp ,nn)
                     (do ((,x ,|00| (add 1 ,x)) (,ii 0 (add 1 ,ii))
                          (,sum nil
@@ -261,7 +229,7 @@
                       (declare (special ,x)))
                     (merror
                      (intl:gettext "makelist: the fourth argument minus the third one must evaluate to a number; found: ~M")
-                     ,nn))))
+                     ,nn)))
               ,|0| ,n))))
     ((= (length form) 5)
      (destructuring-let
@@ -270,8 +238,7 @@
       (setq |0| (dtranslate |0|) n (dtranslate n) s (dtranslate s))
       `($any .
              ((lambda (,|00| ,nn ,ss)
-                (progn
-                  (setq ,nn ($float (div (sub ,nn ,|00|) ,ss)))
+                (setq ,nn ($float (div (sub ,nn ,|00|) ,ss)))
                 (if (numberp ,nn)
                     (do ((,x ,|00| (add ,ss ,x)) (,ii 0 (add 1 ,ii))
                          (,sum nil
@@ -282,12 +249,11 @@
                       (declare (special ,x)))
                     (merror
                      (intl:gettext "makelist: the fourth argument minus the third one, divided by the fifth one must evaluate to a number; found: ~M")
-                     ,nn))))
+                     ,nn)))
               ,|0| ,n ,s))))
     (t
-     (mformat *translation-msgs-files*
-              (intl:gettext "makelist: maximum 5 arguments allowed; found: ~M.~%makelist: to create a list with sublists, use nested makelist commands.~%")
-              (length form))
+     (tr-format (intl:gettext "makelist: maximum 5 arguments allowed; found: ~M.~%makelist: to create a list with sublists, use nested makelist commands.~%")
+                (length form))
      (setq tr-abort t)
      '($any . '$**error**))))
 
@@ -348,66 +314,50 @@
 
 ;;; The following special forms do not call the evaluator.
 
-(def%tr $batcon (form)
-  `($any . (meval ',form)))  
+(def%tr $alias (form)
+  (punt-to-meval form))
+
 ;;most of these will lose in common since a local variable will not
 ;;have its value accessible to the mfexpr*.  They should
 ;;be redone as macros with any necessary info passed along.
 
-(def%tr $remarray           $batcon)
-(def%tr $rearray $batcon)
-(def%tr $alias $batcon)
-(def%tr $alloc $batcon)
-(def%tr $batch $batcon)
-(def%tr $batchload          $batcon)
-(def%tr $closefile $batcon)
-(def%tr $compfile           $batcon)
-(def%tr $delfile $batcon)
-(def%tr $demo $batcon)
-(def%tr $dependencies $batcon)
-(def%tr $describe           $batcon)
-(def%tr $diskfree $batcon)
-(def%tr $diskuse $batcon)
-(def%tr $dispfun $batcon)
-(def%tr $disprule $batcon)
-(def%tr $filelength $batcon)
-(def%tr $filelist $batcon)
-(def%tr $fundef $batcon)
-(def%tr $fulldiskuse $batcon)
-(def%tr $gradef $batcon)
-(def%tr $listfiles $batcon)
-(def%tr $loadfile $batcon)
-(def%tr $loadarrays         $batcon)
-(def%tr $loadplots $batcon)
-(def%tr $namefile $batcon)
-(def%tr $numerval           $batcon)
-(def%tr $options $batcon)
-(def%tr $ordergreat $batcon)
-(def%tr $orderless $batcon)
-(def%tr $plotmode $batcon)
-(def%tr $primer $batcon)
-(def%tr $printdiskuse $batcon)
-(def%tr $printfile $batcon)
-(def%tr $printprops $batcon)
-(def%tr $properties $batcon)
-(def%tr $propvars $batcon)
-(def%tr $qlistfiles $batcon)
-(def%tr $remfile            $batcon)
-(def%tr $remfunction $batcon)
-(def%tr $remove $batcon)
-(def%tr $remvalue           $batcon)
-(def%tr $renamefile $batcon)
-(def%tr $restore $batcon)
-(def%tr $translate          $batcon)
-(def%tr $writefile $batcon)
-(def%tr $hardcopy $batcon)
-(def%tr $labels $batcon)
-(def%tr $setup_autoload $batcon)
-(def%tr $tobreak $batcon  )
-
-;; Kill off the special code for translating sum and product.
-(def%tr $sum $batcon)
-(def%tr $product $batcon)
+(def%tr $batch $alias)
+(def%tr $batchload $alias)
+(def%tr $closefile $alias)
+(def%tr $compfile $alias)
+(def%tr $declare $alias)
+(def%tr $defstruct $alias)
+(def%tr $demo $alias)
+(def%tr $dependencies $alias)
+(def%tr $describe $alias)
+(def%tr $dispfun $alias)
+(def%tr $disprule $alias)
+(def%tr $fundef $alias)
+(def%tr $gradef $alias)
+(def%tr $labels $alias)
+(def%tr $loadarrays $alias)
+(def%tr $loadfile $alias)
+(def%tr $new $alias)
+(def%tr $numerval $alias)
+(def%tr $options $alias)
+(def%tr $ordergreat $alias)
+(def%tr $orderless $alias)
+(def%tr $printfile $alias)
+(def%tr $printprops $alias)
+(def%tr $product $alias)
+(def%tr %product $alias)
+(def%tr $properties $alias)
+(def%tr $propvars $alias)
+(def%tr $rearray $alias)
+(def%tr $remarray $alias)
+(def%tr $remfunction $alias)
+(def%tr $remove $alias)
+(def%tr $remvalue $alias)
+(def%tr $setup_autoload $alias)
+(def%tr $sum $alias)
+(def%tr %sum $alias)
+(def%tr $translate $alias)
+(def%tr $writefile $alias)
 
 ;; Local Modes:
 ;; Mode: LISP
