@@ -14,6 +14,9 @@
 
 (defvar wrap-an-is 'is-boole-check "How to verify booleans")
 
+(defun wrap-an-is (exp)
+  (list wrap-an-is exp))
+
 (def%tr $is (form)
   (let ((wrap-an-is 'is-boole-check))
     (cons '$boolean (translate-predicate (cadr form)))))
@@ -30,6 +33,7 @@
 
 (def-same%tr mequal    mnotequal)
 (def-same%tr $equal    mnotequal)
+(def-same%tr $notequal mnotequal)
 (def-same%tr mgreaterp mnotequal)
 (def-same%tr mgeqp     mnotequal)
 (def-same%tr mlessp    mnotequal)
@@ -43,22 +47,19 @@
 ;;; Note: This TRANSLATE-PREDICATE and TRANSLATE should be combinded
 ;;; to a single function which takes a second argument of the
 ;;; TARGET (mode). Targeting is a pretty basic concept in compilation
-;;; so its suprising this was done. In order to make this change all
-;;; special-forms need to do targetting.
+;;; so its surprising this was done. In order to make this change all
+;;; special-forms need to do targeting.
 
 (defun translate-predicate (form)
   ;; N.B. This returns s-exp, not (<mode> . <s-exp>)
-  (cond ((atom form)
-	 (let ((tform (translate form)))
-	   (cond ((eq '$boolean (car tform)) (cdr tform))
-		 (t
-		  (wrap-an-is (cdr tform) form)))))
+  (cond ((atom form) (trp-with-boolean-convert form))
 	((eq 'mnot (caar form)) (trp-mnot form))
 	((eq 'mand (caar form)) (trp-mand form))
 	((eq 'mor (caar form)) (trp-mor form))
 	((eq 'mnotequal (caar form)) (trp-mnotequal form))
 	((eq 'mequal (caar form)) (trp-mequal form))
 	((eq '$equal (caar form)) (trp-$equal form))
+	((eq '$notequal (caar form)) (trp-$notequal form))
 	((eq 'mgreaterp (caar form)) (trp-mgreaterp form))
 	((eq 'mgeqp (caar form)) (trp-mgeqp form))
 	((eq 'mlessp (caar form)) (trp-mlessp form))
@@ -69,14 +70,13 @@
 	 ;; special form in macsyma!
 	 `(progn ,@(tr-args (nreverse (cdr (reverse (cdr form)))))
 	   ,(translate-predicate (car (last (cdr form))))))
-	(t
-	 (destructuring-let (((mode . tform) (translate form)))
-	   (boolean-convert mode tform form)))))
+	(t (trp-with-boolean-convert form))))
 
-(defun boolean-convert (mode exp form)
-  (if (eq mode '$boolean)
-      exp
-      (wrap-an-is exp form)))
+(defun trp-with-boolean-convert (form)
+  (destructuring-bind (mode . exp) (translate form)
+    (if (eq mode '$boolean)
+        exp
+        (wrap-an-is exp))))
 
 (defun trp-mnot (form) 
   (setq form (translate-predicate (cadr form)))
@@ -99,10 +99,6 @@
 				(t (cons 'or (nreverse nl)))))))
     (cond ((car l) (setq nl (cons (car l) nl))))))
 
-(defun wrap-an-is (exp ignore-form)
-  (declare (ignore ignore-form))
-  (list wrap-an-is exp))
-
 (defvar *number-types* '($float $number $fixnum ))
 
 (defun trp-mgreaterp (form) 
@@ -115,8 +111,7 @@
 	   `(> ,(dconv arg1 mode) ,(dconv arg2 mode)))
 	  ((eq '$number mode) `(> ,(cdr arg1) ,(cdr arg2)))
 	  ('else
-	   (wrap-an-is `(mgrp ,(dconvx arg1) ,(dconvx arg2))
-		       form)))))
+	   (wrap-an-is `(mgrp ,(dconvx arg1) ,(dconvx arg2)))))))
  
 (defun trp-mlessp (form) 
   (let (mode arg1 arg2)
@@ -128,19 +123,14 @@
 	   `(< ,(dconv arg1 mode) ,(dconv arg2 mode)))
 	  ((eq '$number mode) `(< ,(cdr arg1) ,(cdr arg2)))
 	  ('else
-	   (wrap-an-is `(mlsp ,(dconvx arg1) ,(dconvx arg2))
-		       form)))))
+	   (wrap-an-is `(mlsp ,(dconvx arg1) ,(dconvx arg2)))))))
 
 (defun trp-mequal (form) 
-  (let (mode arg1 arg2)
-    (setq arg1 (translate (cadr form)) arg2 (translate (caddr form))
-	  mode (*union-mode (car arg1) (car arg2)))
-    (cond
-      ((or (eq '$fixnum mode)
-	   (eq '$float mode))
-       `(eql ,(dconv arg1 mode) ,(dconv arg2 mode)))
-      ((eq '$number mode) `(equal ,(cdr arg1) ,(cdr arg2)))
-      (t `(like ,(dconv arg1 mode) ,(dconv arg2 mode))))))
+  (destructuring-let (((mode1 . arg1) (translate (cadr form)))
+                      ((mode2 . arg2) (translate (caddr form))))
+    (if (and (covers '$number mode1) (covers '$number mode2))
+        `(eql ,arg1 ,arg2)
+        `(like ,arg1 ,arg2))))
 
 (defun trp-$equal (form) 
   (let (mode arg1 arg2) 
@@ -150,7 +140,7 @@
 	   `(= ,(dconv arg1 mode) ,(dconv arg2 mode)))
 	  ((eq '$number mode) `(meqp ,(cdr arg1) ,(cdr arg2)))
 	  ('else
-	   (wrap-an-is `(meqp ,(dconvx arg1) ,(dconvx arg2)) form)))))
+	   (wrap-an-is `(meqp ,(dconvx arg1) ,(dconvx arg2)))))))
 
 ;; Logical not for predicates.  Do the expected thing, except return
 (defun trp-not (val)
@@ -158,7 +148,10 @@
     ((t) nil)
     ((nil) t)
     (otherwise val)))
-      
+
+(defun trp-$notequal (form)
+  (list 'trp-not (trp-$equal form)))
+
 (defun trp-mnotequal (form)
   (list 'trp-not (trp-mequal form)))
 
@@ -175,7 +168,9 @@
     (do ((nl))
 	((null x)
 	 `($any . (simplify (list '(mlist) ,@(nreverse nl)))))
-      (cond ((eq 'mand (caaar x))
+      (cond ((atom (car x))
+	     (setq nl (cons `(assume ,(dtranslate (car x))) nl)))
+	    ((eq 'mand (caaar x))
 	     (mapc #'(lambda (l) (setq nl (cons `(assume ,(dtranslate l)) nl)))
 		   (cdar x)))
 	    ((eq 'mnot (caaar x))
